@@ -1048,6 +1048,7 @@ void enablerst::eventLoop_SDL()
     if (paused_loop)
       unpause_async_loop();
 
+    hooks_sdl_loop_fn();
     do_frame();
 
 #ifndef NO_FMOD
@@ -1060,7 +1061,7 @@ int enablerst::loop(string cmdline) {
   command_line = cmdline;
 #ifdef WIN32
   glaiel::crashlogs::set_crashlog_folder("crashlogs");
-
+  glaiel::crashlogs::set_crashlog_header_message("Crashed before main menu. Yikes!");
   glaiel::crashlogs::begin_monitoring();
 #endif
   // Initialize the tick counters
