@@ -260,6 +260,72 @@ enum InterfaceKeyType
 	INTERFACEKEY_CUSTOM_ALT_X,
 	INTERFACEKEY_CUSTOM_ALT_Y,
 	INTERFACEKEY_CUSTOM_ALT_Z,
+	INTERFACEKEY_CUSTOM_UP,
+	INTERFACEKEY_CUSTOM_DOWN,
+	INTERFACEKEY_CUSTOM_LEFT,
+	INTERFACEKEY_CUSTOM_RIGHT,
+	INTERFACEKEY_CUSTOM_TAB,
+	INTERFACEKEY_CUSTOM_HOME,
+	INTERFACEKEY_CUSTOM_END,
+	INTERFACEKEY_CUSTOM_PGUP,
+	INTERFACEKEY_CUSTOM_PGDN,
+	INTERFACEKEY_CUSTOM_INSERT,
+	INTERFACEKEY_CUSTOM_DELETE,
+
+	INTERFACEKEY_CUSTOM_SHIFT_ENTER,
+	INTERFACEKEY_CUSTOM_SHIFT_BACKSPACE,
+	INTERFACEKEY_CUSTOM_SHIFT_UP,
+	INTERFACEKEY_CUSTOM_SHIFT_DOWN,
+	INTERFACEKEY_CUSTOM_SHIFT_LEFT,
+	INTERFACEKEY_CUSTOM_SHIFT_RIGHT,
+	INTERFACEKEY_CUSTOM_SHIFT_TAB,
+	INTERFACEKEY_CUSTOM_SHIFT_HOME,
+	INTERFACEKEY_CUSTOM_SHIFT_END,
+	INTERFACEKEY_CUSTOM_SHIFT_PGUP,
+	INTERFACEKEY_CUSTOM_SHIFT_PGDN,
+	INTERFACEKEY_CUSTOM_SHIFT_INSERT,
+	INTERFACEKEY_CUSTOM_SHIFT_DELETE,
+
+	INTERFACEKEY_CUSTOM_CTRL_ENTER,
+	INTERFACEKEY_CUSTOM_CTRL_BACKSPACE,
+	INTERFACEKEY_CUSTOM_CTRL_UP,
+	INTERFACEKEY_CUSTOM_CTRL_DOWN,
+	INTERFACEKEY_CUSTOM_CTRL_LEFT,
+	INTERFACEKEY_CUSTOM_CTRL_RIGHT,
+	INTERFACEKEY_CUSTOM_CTRL_TAB,
+	INTERFACEKEY_CUSTOM_CTRL_HOME,
+	INTERFACEKEY_CUSTOM_CTRL_END,
+	INTERFACEKEY_CUSTOM_CTRL_PGUP,
+	INTERFACEKEY_CUSTOM_CTRL_PGDN,
+	INTERFACEKEY_CUSTOM_CTRL_INSERT,
+	INTERFACEKEY_CUSTOM_CTRL_DELETE,
+	INTERFACEKEY_CUSTOM_CTRL_SLASH,
+	INTERFACEKEY_CUSTOM_CTRL_0,
+	INTERFACEKEY_CUSTOM_CTRL_1,
+	INTERFACEKEY_CUSTOM_CTRL_2,
+	INTERFACEKEY_CUSTOM_CTRL_3,
+	INTERFACEKEY_CUSTOM_CTRL_4,
+	INTERFACEKEY_CUSTOM_CTRL_5,
+	INTERFACEKEY_CUSTOM_CTRL_6,
+	INTERFACEKEY_CUSTOM_CTRL_7,
+	INTERFACEKEY_CUSTOM_CTRL_8,
+	INTERFACEKEY_CUSTOM_CTRL_9,
+
+	INTERFACEKEY_CUSTOM_CTRL_SHIFT_UP,
+	INTERFACEKEY_CUSTOM_CTRL_SHIFT_DOWN,
+	INTERFACEKEY_CUSTOM_CTRL_SHIFT_LEFT,
+	INTERFACEKEY_CUSTOM_CTRL_SHIFT_RIGHT,
+
+	INTERFACEKEY_CUSTOM_ALT_0,
+	INTERFACEKEY_CUSTOM_ALT_1,
+	INTERFACEKEY_CUSTOM_ALT_2,
+	INTERFACEKEY_CUSTOM_ALT_3,
+	INTERFACEKEY_CUSTOM_ALT_4,
+	INTERFACEKEY_CUSTOM_ALT_5,
+	INTERFACEKEY_CUSTOM_ALT_6,
+	INTERFACEKEY_CUSTOM_ALT_7,
+	INTERFACEKEY_CUSTOM_ALT_8,
+	INTERFACEKEY_CUSTOM_ALT_9,
 
 	WORLDKEY_START,
 	/*
